summaryrefslogtreecommitdiffstats
path: root/kword/KWFrameView.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /kword/KWFrameView.h
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kword/KWFrameView.h')
-rw-r--r--kword/KWFrameView.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/kword/KWFrameView.h b/kword/KWFrameView.h
index d7b63aba..c7017bf7 100644
--- a/kword/KWFrameView.h
+++ b/kword/KWFrameView.h
@@ -38,19 +38,19 @@ public:
/** Constructor */
FramePolicy(KWFrameView *view);
/**
* Return the MouseMeaning enum value for the tqparent view.
* @param point the point where the mouse is hovering.
- * @param keyState the bittqmask of keys that are pressed. Same as Event::state();
+ * @param keyState the bitmask of keys that are pressed. Same as Event::state();
*/
virtual MouseMeaning mouseMeaning( const KoPoint &point, int keyState ) = 0;
/**
* Return a fully initialized popup for the context of frame at @p point
* @param point the point where the mouse is hovering.
* @param view the tqparent view widget
*/
virtual TQPopupMenu* createPopup( const KoPoint &point, KWView *view ) = 0;
/**
* Override this method to do more than select the tqparent frame-view
*/
virtual void setSelected(MouseMeaning) { }
@@ -58,12 +58,12 @@ protected:
/**
* Shared method for all policies called when the border of the frame is clicked.
* @param point the point where the mouse is hovering.
- * @param keyState the bittqmask of keys that are pressed. Same as Event::state();
+ * @param keyState the bitmask of keys that are pressed. Same as Event::state();
*/
virtual MouseMeaning mouseMeaningOnBorder(const KoPoint &point, int keyState);
/**
* Shared method for all policies to add the 'set floating' action to a popup menu.
* @param view the tqparent view widget
* @param actionList the list of actions where the floating action should be added to
*/
void addFloatingAction(KWView *view, TQPtrList<KAction> &actionList);
@@ -83,10 +83,10 @@ class KWFrameView {
public:
/**
* Constructor
* @param tqparent the tqparent
* @param frame the frame this view represents.
*/
- KWFrameView(KWFrameViewManager *tqparent, KWFrame *frame);
+ KWFrameView(KWFrameViewManager *parent, KWFrame *frame);
virtual ~KWFrameView();
/// returns if this frameView is selected. A selected frame is shown differently on screen.
@@ -108,22 +108,22 @@ public:
bool contains(const KoPoint &point, bool fuzzy = true) const;
/**
* Return the MouseMeaning enum value for the tqparent view.
* @param point the point where the mouse is hovering.
- * @param keyState the bittqmask of keys that are pressed. Same as Event::state();
+ * @param keyState the bitmask of keys that are pressed. Same as Event::state();
*/
MouseMeaning mouseMeaning( const KoPoint &point, int keyState );
- /// Return the tqparent KWFrameViewManager this frameView belongs to
- KWFrameViewManager *tqparent() const { return m_manager; }
+ /// Return the parent KWFrameViewManager this frameView belongs to
+ KWFrameViewManager *parent() const { return m_manager; }
/**
* Show a context-sensitive popup menu based on the location of 'point'.
* @param point the point at which the mouse was clicked. The context is based on
* what is present at that location.
* @param popupPoint the point in the same coordinate system as the tqparent widget of
* where the popup menu should be located.
* @param view the tqparent widget for the popup.
*/
void showPopup( const KoPoint &point, KWView *view, const TQPoint &popupPoint) const;
@@ -38,19 +38,19 @@ public:
FramePolicy(KWFrameView *view);
/**
- * Return the MouseMeaning enum value for the tqparent view.
+ * Return the MouseMeaning enum value for the parent view.
* @param point the point where the mouse is hovering.
@@ -38,19 +38,19 @@ public:
* Return a fully initialized popup for the context of frame at @p point
* @param point the point where the mouse is hovering.
- * @param view the tqparent view widget
+ * @param view the parent view widget
*/
virtual TQPopupMenu* createPopup( const KoPoint &point, KWView *view ) = 0;
@@ -38,19 +38,19 @@ public:
virtual TQPopupMenu* createPopup( const KoPoint &point, KWView *view ) = 0;
/**
- * Override this method to do more than select the tqparent frame-view
+ * Override this method to do more than select the parent frame-view
*/
virtual void setSelected(MouseMeaning) { }
@@ -58,12 +58,12 @@ protected:
/**
* Shared method for all policies to add the 'set floating' action to a popup menu.
- * @param view the tqparent view widget
+ * @param view the parent view widget
* @param actionList the list of actions where the floating action should be added to
*/
@@ -83,10 +83,10 @@ class KWFrameView {
/**
* Constructor
- * @param tqparent the tqparent
+ * @param parent the parent
* @param frame the frame this view represents.
*/
@@ -108,22 +108,22 @@ public:
bool contains(const KoPoint &point, bool fuzzy = true) const;
/**
- * Return the MouseMeaning enum value for the tqparent view.
+ * Return the MouseMeaning enum value for the parent view.
* @param point the point where the mouse is hovering.
@@ -108,22 +108,22 @@ public:
* @param point the point at which the mouse was clicked. The context is based on
* what is present at that location.
- * @param popupPoint the point in the same coordinate system as the tqparent widget of
+ * @param popupPoint the point in the same coordinate system as the parent widget of
* where the popup menu should be located.
@@ -108,22 +108,22 @@ public:
* where the popup menu should be located.
- * @param view the tqparent widget for the popup.
+ * @param view the parent widget for the popup.
*/
void showPopup( const KoPoint &point, KWView *view, const TQPoint &popupPoint) const;